// Copyright (c) 2003-2010 Christopher M. Kohlhoff
// Modifications (c) 2011 by Guilherme Maciel Ferreira / Intra2net AG
//
// Distributed under the Boost Software License, Version 1.0.
//    (See accompanying file LICENSE_1_0.txt or copy at
//          http://www.boost.org/LICENSE_1_0.txt)
#ifndef ICMP_GENERIC_MESSAGE_H
#define ICMP_GENERIC_MESSAGE_H

#include <stdint.h>

#include <istream>
#include <ostream>

#include "icmp/icmpmessage.h"

//-----------------------------------------------------------------------------
// IcmpGenericMessage
//-----------------------------------------------------------------------------

/**
 * This class intends to handle ICMP messages that the application do not
 * want to read. It acts like a stub.
 */
class IcmpGenericMessage : public IcmpMessage
{
public:
    IcmpGenericMessage();
    virtual ~IcmpGenericMessage();

    virtual Icmpv4Type get_type_v4() const;
    virtual void set_type_v4( const Icmpv4Type type );

    virtual Icmpv6Type get_type_v6() const;
    virtual void set_type_v6( const Icmpv6Type type );

    virtual uint8_t get_code() const;
    virtual void set_code( const uint8_t code );

    virtual uint16_t get_checksum() const;
    virtual void set_checksum( const uint16_t checksum );

    virtual uint16_t get_identifier() const;
    virtual void set_identifier( const uint16_t identifier );

    virtual uint16_t get_sequence_number() const;
    virtual void set_sequence_number( const uint16_t sequence_number );

    virtual std::istream& read( std::istream &is );
    virtual std::ostream& write( std::ostream &os ) const;

};

#endif // ICMP_GENERIC_MESSAGE_H
